fidetournament
==============

.. image:: https://travis-ci.org/erral/fidetournament.svg?branch=master
    :target: https://travis-ci.org/erral/fidetournament

.. image:: https://coveralls.io/repos/github/erral/fidetournament/badge.svg?branch=master
    :target: https://coveralls.io/github/erral/fidetournament?branch=master


FIDE Tournament Report File (Krause format) parser and creator


Ref: http://ruby-doc.org/gems/docs/i/icu_tournament-1.6.8/ICU/Tournament/Krause.html

Format:
    Explanation: http://ratings.fide.com/download/fidexchg.txt
    Example file: http://ratings.fide.com/download/example1.txt
